#ifndef LAVADERO_H
#define LAVADERO_H


/*
 * Tipo Abstracto de Datos del lavadero
 * Implementa el tipo algebraico del conjunto de enteros [0,N), 
 * mediante un poco eficiente, en terminos de memoria, bitmap.
 * 
 * Las operaciones basicas son quitar algun elemento, agregar y pertenencia.
 * 
 * La idea es que m \in L, sii la maquina m esta libre en el lavadero L.
 */


#include "datatypes.h"

/*
 * La estructura se compone de un bitmap indicando que maquinas estan
 * disponibles y la cantidad de maquinas con que se cuenta
 */
struct lavadero_s {
	int tamanio;
	bool *disponibles;
};

/* 
 * Un lavadero es un puntero a la estructura para poder devolverlo facilmente
 */
typedef struct lavadero_s* lavadero;

/*
 * Prototipos de las funciones del TAD
 */
lavadero lavadero_crear(int t);
void lavadero_destruir(lavadero l);
int lavadero_tamanio(lavadero l);
maquina lavadero_pedir_maquina(lavadero l);
void lavadero_devolver_maquina(lavadero l, maquina m);
bool lavadero_libre_maquina(lavadero l, maquina m);

#endif
